@@ -37,10 +37,11 @@ def top_keyword_multiprocessing(appid_list, keyword_hot_start, start_time, end_t
     p.join()
 
 def multiprocessing_run(appid, keyword_hot_start, start_time, end_time, file_path):
-    appname = get_app_appinfo(appid).get_subname()
-    print("\n【%s】子进程开始，进程ID：%d" % (appname, os.getpid()))
-    start = time.time()
+    appname = Get_App_Appinfo(appid).get_subname()
+    print("【%s】子进程开始，进程ID：%d\n" % (appname, os.getpid()))
+    old_seconds = datetime.datetime.now()
     get_top_keyword(appid, keyword_hot_start, start_time, end_time).df_to_excel(file_path)
-    end = time.time()
-    print("【%s】子进程结束，进程ID：%d。耗时0.2%f" % (appname, os.getpid(), end-start))
+    now_seconds = datetime.datetime.now()
+    interval_seconds =round((now_seconds - old_seconds).seconds/60, 2)
+    print("【%s】子进程结束，进程ID：%d；当前 %s ，耗时%s分钟" % (appname, os.getpid(), str(now_seconds)[:19], interval_seconds))
 
