@@ -1,7 +1,7 @@
 from qm_spider import *
 
 
-class get_top_keyword:
+class Get_Top_Keyword:
     def __init__(self, appid, keyword_hot_start, start_time, end_time, keyword_hot_end=150000):
         self.keyword_hot_start = keyword_hot_start
         self.keyword_hot_end = keyword_hot_end
@@ -17,7 +17,7 @@ class get_top_keyword:
         )
 
     def get_all_top(self):
-        self.app_name = get_app_appinfo(self.appid).get_subname()
+        self.app_name = Get_App_Appinfo(self.appid).get_subname()
         self.t1_all_list = []
         self.t2_all_list = []
         self.t3_all_list = []
@@ -27,12 +27,12 @@ class get_top_keyword:
         self.now_app_list = []
         print('==========开始获取【%s】产品相关数据==========' %(self.app_name))
         while self.start_time <= self.end_time:
-            get_app_keyword_data = get_app_keyword(self.appid)
+            get_app_keyword_data = Get_App_Keyword(self.appid)
             get_app_keyword_data.run_time = self.start_time
             get_app_keyword_data.keyword_hot_start = self.keyword_hot_start
             res = get_app_keyword_data.get_keywordDetail()
             if res['msg'] == '成功' and len(res['data']) > 0:
-                df_keyword = qimai_outside_tool(res['data']).json_to_df()
+                df_keyword = Qimai_Outside_Tool(*[res['data']]).json_to_df()
                 df_keyword.columns = ['关键词ID', '关键词', '排名', '变动前排名', '排名变动值', '指数', '结果数', '未知1', '未知2']
 
                 t1_all_num = df_keyword[(df_keyword['排名'] <= 1) & (df_keyword['指数'] >= self.keyword_hot_start) & (df_keyword['指数'] <= self.keyword_hot_end) & (df_keyword['排名变动值'] != 'lost')].shape[0]
@@ -72,11 +72,11 @@ class get_top_keyword:
         return df
 
 
-class get_multiple_top_keyword():
+class Get_Multiple_Top_Keyword():
     def __init__(self, appid_list, keyword_hot_start, start_time, end_time, file_path='./'):
         for appid in appid_list:
-            app_name = get_app_appinfo(appid).get_subname()
-            df = get_top_keyword(appid, keyword_hot_start, start_time, end_time).get_all_top()
+            app_name = Get_App_Appinfo(appid).get_subname()
+            df = Get_Top_Keyword(appid, keyword_hot_start, start_time, end_time).get_all_top()
             df.to_excel(
                 '%s%s_%s_Top关键词数据.xlsx' %(file_path, end_time, app_name), encoding='utf-8-sig', index=False
             )
\ No newline at end of file
